@@ -32,7 +32,7 @@
   #define XDMF_BYTE_ORDER_LITTLE
 #endif
 
-#define XDMF_SYSTEM Linux-5.1.16-1-ARCH
+#define XDMF_SYSTEM Linux-6.17.7-3-aarch64-ARCH
 
 #define XDMF_VOID_VALID
 #ifndef XDMF_VOID_VALID
